#
# spec file for package arista
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           arista
Version:        0.9.7
Release:        5.2
License:        LGPL-2.1+
Summary:        Preset-based transcoder for the GNOME Desktop
Url:            http://www.transcoder.org/
Group:          Productivity/Multimedia/Video/Editors and Convertors
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE arista-remove-shebangs.patch badshah400@gmail.com -- Remove shebangs from .py files
Patch0:         arista-remove-shebangs.patch
# PATCH-FIX-OPENSUSE arista-add-missing-man-pages.patch malcolmlewis@opensuse.org -- Add missing arista-gtk and arista-transcode man pages, see https://github.com/danielgtaylor/arista/pull/97
Patch1:         arista-add-missing-man-pages.patch
BuildRequires:  fdupes
# For directory ownership
BuildRequires:  python-nautilus
BuildRequires:  update-desktop-files
Requires:       gstreamer-0_10-plugins-bad
Requires:       gstreamer-0_10-plugins-base
Requires:       gstreamer-0_10-plugins-good
Requires:       gstreamer-0_10-plugins-ugly
Requires:       python-gudev
%if 0%{?suse_version} <= 1130
# For gconf
Requires:       python-gnome
%else
Requires:       python-gconf
%endif
Requires:       python-gstreamer-0_10
Requires:       python-gtk
Requires:       python-notify
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%py_requires
%if %suse_version <= 1110
%define python_sitelib %{py_sitedir}
%endif

%description
Arista is a simple preset-based transcoder for the GNOME Desktop and a
small script for terminal-based transcoding. Settings are chosen based
on output device and quality preset.

Features:
 * Presets for Android, iPod, computer, DVD player, PSP, and more
 * Live preview to see encoded quality
 * Automatically discover available DVD drives and media
 * Rip straight from DVD media easily
 * Automatically discover and record from Video4Linux devices
 * Support for H.264, WebM, FLV, Ogg, DivX and more
 * Batch processing of entire directories easily
 * Simple terminal client for scripting
 * Nautilus extension for right-click file conversion

%package -n nautilus-extension-arista
License:        LGPL-2.1+
Summary:        Arista extension for Nautilus
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}
Requires:       python-nautilus
Supplements:    packageand(%{name}:nautilus)

%description -n nautilus-extension-arista
Arista is a simple preset-based transcoder for the GNOME Desktop and a
small script for terminal-based transcoding. Settings are chosen based
on output device and quality preset.

Features:
 * Presets for Android, iPod, computer, DVD player, PSP, and more
 * Live preview to see encoded quality
 * Automatically discover available DVD drives and media
 * Rip straight from DVD media easily
 * Automatically discover and record from Video4Linux devices
 * Support for H.264, WebM, FLV, Ogg, DivX and more
 * Batch processing of entire directories easily
 * Simple terminal client for scripting
 * Nautilus extension for right-click file conversion

This package contains a Nautilus extension to add Arista based actions.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build

%install
%{__python} setup.py install --prefix=%{_prefix} --exec-prefix=%{_exec_prefix} --root=%{buildroot}
# Remove files we install with %%doc
rm %{buildroot}%{_datadir}/doc/arista/{AUTHORS,LICENSE,README.md}
# Remove file that should not get installed
rm %{buildroot}%{_datadir}/locale/templates/arista.pot
%suse_update_desktop_file arista AudioVideoEditing
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/arista/

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS LICENSE README.md
%{_bindir}/arista-gtk
%{_bindir}/arista-transcode
%{_datadir}/applications/arista.desktop
%{_datadir}/arista/
%{_mandir}/man1/*.gz
%{python_sitelib}/arista/
%{python_sitelib}/*.egg-info

%files -n nautilus-extension-arista
%defattr(-,root,root)
%{_datadir}/nautilus-python/extensions/arista-nautilus.py*

%files lang -f %{name}.lang

%changelog
* Tue Oct 25 2011 coolo@suse.com
- fix a FIXME - hal is gone, python-gudev is there
  + Drop hal and dbus-1-python BuildRequires and add python-gudev
    in place.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Jun 23 2011 malcolmlewis@opensuse.org
- Update to version 0.9.7:
  + UI restructured, the ability to edit and manage presets,
    drag and drop support.
  + Updated presets.
  + Various bug fixes.
  + Updated translations.
- Update spec file Licence field from LGPLv2.1+ to LGPL-2.1+ to
  conform with spdx.org identifier.
- Drop arista-pycompile.patch: fixed upstream.
- Add arista-add-missing-man-pages.patch for missing arista-gtk
  and arista-transcode man pages.
* Thu Jun  9 2011 vuntz@opensuse.org
- On 11.4 and later, change python-gnome Requires to python-gconf
  since this is the only module being used from python-gnome.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Fri Jan  7 2011 vuntz@opensuse.org
- Remove dbus-1-python, python-gobject2, python-gtk, python-notify
  BuildRequires as they are not needed.
- Add hal, python-gnome, python-gtk Requires: they're needed at
  runtime. Note that we'll be able to remove hal once we have
  python-gudev.
- Do not own %%{_datadir}/nautilus-python/extensions/ as
  python-nautilus now owns it.
- Change the fdupes call to catch more duplicate files in
  %%{_datadir}/arista.
* Mon Dec 27 2010 dimstar@opensuse.org
- Update to version 0.9.6:
  + Updated default presets
  + Allow video transforms in templates
  + UI improvements
  + Prevent Nautilus from locking up
  + Implement DVD main feature title auto-discovery
  + Various ug fixes
- Add arista-pycompile.patch: allow byte-compiling a py file that
  is installed in a install_root. Reported upstream issue
  https://github.com/danielgtaylor/arista/issues#issue/54
- Stop moving files around in install: arista-bytecompile.patch
  fixes that as well.
- Make the package noarch.
* Tue Sep 21 2010 vuntz@opensuse.org
- Rename nautilus-arista to nautilus-extension-arista.
- Move python-nautilus Requires to nautilus-extension-arista.
* Mon Sep 13 2010 badshah400@gmail.com
- Added post-install script to make arista's nautilus actions work
  in 64-bit configurations
* Sat Sep 11 2010 badshah400@gmail.com
- Split a nautilus-arista subpackage for the nautilus extension
- Major clean-up of spec file
  + Expanded on package description
  + Revert previous modifications to fix build errors on openSUSE
    11.1 and 11.2, depends on python-nautilus only in GNOME:Apps
    for these openSUSE versions
  + Fix License tag as LGPLv2.1+ instead of GPLv2
  + Recommend arista-lang instead of arista-0.9.5-lang
* Tue Sep  7 2010 badshah400@gmail.com
- Fix build errors on openSUSE 11.1 and 11.2
* Tue Sep  7 2010 badshah400@gmail.com
- Initial package (version 0.9.5)
